@@ -14,7 +14,7 @@ from glean_parser import translate
 ROOT = Path(__file__).parent
 
 
-def test_parser(tmpdir):
+def test_parser_js(tmpdir):
     """Test translating metrics to Javascript files."""
     tmpdir = Path(str(tmpdir))
 
@@ -39,14 +39,56 @@ def test_parser(tmpdir):
     # Make sure descriptions made it in
     with (tmpdir / "corePing.js").open("r", encoding="utf-8") as fd:
         content = fd.read()
+        assert "use strict" in content
         assert "True if the user has set Firefox as the default browser." in content
 
     with (tmpdir / "telemetry.js").open("r", encoding="utf-8") as fd:
         content = fd.read()
+        assert "use strict" in content
         assert "جمع 搜集" in content
 
     with (tmpdir / "gleanInternalMetrics.js").open("r", encoding="utf-8") as fd:
         content = fd.read()
+        assert "use strict" in content
+        assert 'category: ""' in content
+
+
+def test_parser_ts(tmpdir):
+    """Test translating metrics to Typescript files."""
+    tmpdir = Path(str(tmpdir))
+
+    translate.translate(
+        ROOT / "data" / "core.yaml",
+        "typescript",
+        tmpdir,
+        None,
+        {"allow_reserved": True},
+    )
+
+    assert set(x.name for x in tmpdir.iterdir()) == set(
+        [
+            "corePing.ts",
+            "telemetry.ts",
+            "environment.ts",
+            "dottedCategory.ts",
+            "gleanInternalMetrics.ts",
+        ]
+    )
+
+    # Make sure descriptions made it in
+    with (tmpdir / "corePing.ts").open("r", encoding="utf-8") as fd:
+        content = fd.read()
+        assert "use strict" not in content
+        assert "True if the user has set Firefox as the default browser." in content
+
+    with (tmpdir / "telemetry.ts").open("r", encoding="utf-8") as fd:
+        content = fd.read()
+        assert "use strict" not in content
+        assert "جمع 搜集" in content
+
+    with (tmpdir / "gleanInternalMetrics.ts").open("r", encoding="utf-8") as fd:
+        content = fd.read()
+        assert "use strict" not in content
         assert 'category: ""' in content
 
 
@@ -87,7 +129,7 @@ def test_metric_class_name():
         extra_keys={"my_extra": {"description": "an extra"}},
     )
 
-    assert javascript.class_name(event.type) == "Glean._private.EventMetricType"
+    assert javascript.class_name(event.type) == "EventMetricType"
 
     boolean = metrics.Boolean(
         type="boolean",
@@ -98,7 +140,7 @@ def test_metric_class_name():
         description="description...",
         expires="never",
     )
-    assert javascript.class_name(boolean.type) == "Glean._private.BooleanMetricType"
+    assert javascript.class_name(boolean.type) == "BooleanMetricType"
 
     ping = pings.Ping(
         name="custom",
@@ -107,7 +149,42 @@ def test_metric_class_name():
         bugs=["http://bugzilla.mozilla.com/12345"],
         notification_emails=["nobody@nowhere.com"],
     )
-    assert javascript.class_name(ping.type) == "Glean._private.PingType"
+    assert javascript.class_name(ping.type) == "PingType"
+
+
+def test_import_path():
+    event = metrics.Event(
+        type="event",
+        category="category",
+        name="metric",
+        bugs=["http://bugzilla.mozilla.com/12345"],
+        notification_emails=["nobody@example.com"],
+        description="description...",
+        expires="never",
+        extra_keys={"my_extra": {"description": "an extra"}},
+    )
+
+    assert javascript.import_path(event.type) == "metrics/event"
+
+    boolean = metrics.Boolean(
+        type="boolean",
+        category="category",
+        name="metric",
+        bugs=["http://bugzilla.mozilla.com/12345"],
+        notification_emails=["nobody@example.com"],
+        description="description...",
+        expires="never",
+    )
+    assert javascript.import_path(boolean.type) == "metrics/boolean"
+
+    ping = pings.Ping(
+        name="custom",
+        description="description...",
+        include_client_id=True,
+        bugs=["http://bugzilla.mozilla.com/12345"],
+        notification_emails=["nobody@nowhere.com"],
+    )
+    assert javascript.import_path(ping.type) == "ping"
 
 
 # TODO: Activate once Glean.js adds support for labeled metric types in Bug 1682573.
@@ -189,5 +266,5 @@ def test_arguments_are_generated_in_deterministic_order(tmpdir):
     with (tmpdir / "event.js").open("r", encoding="utf-8") as fd:
         content = fd.read()
         content = " ".join(content.split())
-        expected = 'new Glean._private.EventMetricType({ category: "event", name: "example", sendInPings: ["events"], lifetime: "ping", disabled: false, }, ["alice", "bob", "charlie"]),'  # noqa
+        expected = 'export const example = new EventMetricType({ category: "event", name: "example", sendInPings: ["events"], lifetime: "ping", disabled: false, }, ["alice", "bob", "charlie"]);'  # noqa
         assert expected in content
